{% load i18n %}
{% load static %}

{% load unicms_menus %}

{% load_other_items_from_menu exclude_item=False as items %}


{% include "unical_menu_buttons.html" with items=items.items current=items.current title=items.parent.name %}
